# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/neoscr',
                'doc_host': 'https://datarisk-io.github.io',
                'git_url': 'https://github.com/datarisk-io/neoscr',
                'lib_path': 'neoscr'},
  'syms': { 'neoscr.cli': { 'neoscr.cli.build_package': ('cli.html#build_package', 'neoscr/cli.py'),
                            'neoscr.cli.consulta_scr': ('cli.html#consulta_scr', 'neoscr/cli.py'),
                            'neoscr.cli.install_package': ('cli.html#install_package', 'neoscr/cli.py')},
            'neoscr.core': { 'neoscr.core.ConsultaSCR': ('core.html#consultascr', 'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR.__init__': ('core.html#consultascr.__init__', 'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR._get_resumo_cliente_traduzido': ( 'core.html#consultascr._get_resumo_cliente_traduzido',
                                                                                        'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR._get_resumo_lista_das_operacoes': ( 'core.html#consultascr._get_resumo_lista_das_operacoes',
                                                                                          'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR._get_resumo_modalidade': ( 'core.html#consultascr._get_resumo_modalidade',
                                                                                 'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR._request': ('core.html#consultascr._request', 'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR.get_cnpj_data': ('core.html#consultascr.get_cnpj_data', 'neoscr/core.py'),
                             'neoscr.core.ConsultaSCR.get_cpf_data': ('core.html#consultascr.get_cpf_data', 'neoscr/core.py')},
            'neoscr.utils': { 'neoscr.utils.fill_zeros': ('utils.html#fill_zeros', 'neoscr/utils.py'),
                              'neoscr.utils.format_cnpj': ('utils.html#format_cnpj', 'neoscr/utils.py'),
                              'neoscr.utils.format_cpf': ('utils.html#format_cpf', 'neoscr/utils.py'),
                              'neoscr.utils.let_only_digits': ('utils.html#let_only_digits', 'neoscr/utils.py')}}}
